X-Git-Url: https://git.p6c8.net/jirafeau.git/blobdiff_plain/045f02b53953998c9cb0cff34f7f62664bdd66cd..91938ace0f73ee6bdfbc44956cd2e1652c9c8297:/lib/config.original.php?ds=sidebyside
diff --git a/lib/config.original.php b/lib/config.original.php
index 7323814..c38e640 100644
--- a/lib/config.original.php
+++ b/lib/config.original.php
@@ -15,15 +15,15 @@
* GNU Affero General Public License for more details.
*
* You should have received a copy of the GNU Affero General Public License
- * along with this program. If not, see .
+ * along with this program. If not, see .
*/
-
+
/*
* default configuration
* if you want to change this, overwrite in a config.local.php file
*/
global $cfg;
-
+
/* Don't forget the ending '/' */
$cfg['web_root'] = '';
$cfg['var_root'] = '';
@@ -34,17 +34,15 @@ $cfg['var_root'] = '';
*/
$cfg['lang'] = 'auto';
/* Select your style :) See media folder */
-$cfg['style'] = 'modern';
-/* Propose a preview link if file type is previewable is set to true. */
+$cfg['style'] = 'courgette';
+/* Propose a preview link if file type is previewable. */
$cfg['preview'] = true;
-/* Download page: propose a link to a download page is set to true. */
-$cfg['download_page'] = true;
/* Encryption feature. disable it by default.
* By enabling it, file-level deduplication won't work.
*/
$cfg['enable_crypt'] = false;
-/* Split lenght of link refenrece. */
-$cfg['link_name_lenght'] = 8;
+/* Split length of link refenrece. */
+$cfg['link_name_length'] = 8;
/* Upload password(s). Empty array disable password authentification.
* $cfg['upload_password'] = array(); // No password
* $cfg['upload_password'] = array('psw1'); // One password
@@ -52,8 +50,16 @@ $cfg['link_name_lenght'] = 8;
* ... and so on
*/
$cfg['upload_password'] = array();
+/* List of IP allowed to upload a file.
+ * If list is empty, then there is no upload restriction based on IP
+ * Elements of the list can be a single IP (e.g. "123.45.67.89") or
+ * an IP range (e.g. "123.45.0.0/16").
+ * Note that CIDR notation is available for IPv4 only for the moment.
+ */
+$cfg['upload_ip'] = array();
/* An empty admin password will disable the classic admin password
- * authentication.
+ * authentication. Note that admin password is a sha256 hash of the original
+ * version.
*/
$cfg['admin_password'] = '';
/* If set, let's the user to be authenticated as administrator.
@@ -63,6 +69,41 @@ $cfg['admin_password'] = '';
* If admin_password parameter is also set, admin_password is ignored.
*/
$cfg['admin_http_auth_user'] = '';
+/* Select different options for availability of uploaded files.
+ * Possible values in array:
+ * 'minute': file is available for one minute
+ * 'hour': file available for one hour
+ * 'day': file available for one day
+ * 'week': file available for one week
+ * 'month': file is available for one month
+ * 'year': file available for one year
+ * 'none': unlimited availability
+ */
+$cfg['availabilities'] = array (
+ 'minute' => true,
+ 'hour' => true,
+ 'day' => true,
+ 'week' => true,
+ 'month' => true,
+ 'quarter' => false,
+ 'year' => false,
+ 'none' => false
+);
+/* Set a default value for the expiration time.
+ * The value has to equal one of the enabled options in »availabilities«, e.g. »month«)
+ */
+$cfg['availability_default'] = 'month';
+/* Set maximal upload size expressed in MB.
+ * 0 mean unlimited upload size.
+ */
+$cfg['maximal_upload_size'] = 0;
+/* If your Jirafeau is behind some reverse proxies, you can set there IPs
+ * so Jirafeau get visitor's IP from HTTP_X_FORWARDED_FOR instead of
+ * REMOTE_ADDR.
+ * for example:
+ * $cfg['proxy_ip'] = array('12.34.56.78');
+ */
+$cfg['proxy_ip'] = array();
/* Installation is done ? */
$cfg['installation_done'] = false;